<?xml version="1.0" encoding="UTF-8"?>
<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/">
  <channel rdf:about="http://blog.gmane.org/gmane.linux.busybox">
    <title>gmane.linux.busybox</title>
    <link>http://blog.gmane.org/gmane.linux.busybox</link>
    <description/>
    <syn:updatePeriod>hourly</syn:updatePeriod>
    <syn:updateFrequency>1</syn:updateFrequency>
    <syn:updateBase>1901-01-01T00:00+00:00</syn:updateBase>
    <items>
      <rdf:Seq>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37651"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37647"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37640"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37635"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37633"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37631"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37624"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37614"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37605"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37598"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37592"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37581"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37577"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37576"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37573"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37562"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37559"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37557"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37552"/>
        <rdf:li rdf:resource="http://comments.gmane.org/gmane.linux.busybox/37543"/>
      </rdf:Seq>
    </items>
    <image rdf:resource="http://gmane.org/img/gmane-25t.png"/>
    <textinput rdf:resource=""/>
  </channel>
  <image rdf:about="http://gmane.org/img/gmane-25t.png">
    <title>Gmane</title>
    <url>http://gmane.org/img/gmane-25t.png</url>
    <link>http://gmane.org</link>
  </image>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37651">
    <title>New shell command: prlimit</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37651</link>
    <description>&lt;pre&gt;The attached patch adds a new shell builtin, "prlimit", which is similar
to ulimit but can operate on any process (not just the current process),
by using Linux's prlimit() function.

prlimit takes a PID as a first argument, and then processes the rest of
its arguments identically to ulimit, e.g.:

prlimit 3431 -c unlimited

Maybe this is of general interest?

&lt;/pre&gt;</description>
    <dc:creator>Joshua Judson Rosen</dc:creator>
    <dc:date>2013-05-23T02:53:42</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37647">
    <title>[PATCH] date: accept 'yyyy-mm-dd HH' and 'yyyy-mm-dd' date formats.</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37647</link>
    <description>&lt;pre&gt;This makes busybox date more compatible with coreutils and fixes a TODO
in libbb/time.c.

Signed-off-by: Bartosz Golaszewski &amp;lt;bartekgola&amp;lt; at &amp;gt;gmail.com&amp;gt;
---
 libbb/time.c |   16 ++++++++++++++--
 1 file changed, 14 insertions(+), 2 deletions(-)

diff --git a/libbb/time.c b/libbb/time.c
index 57e14b6..3d8305d 100644
--- a/libbb/time.c
+++ b/libbb/time.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -58,7 +58,6 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; void FAST_FUNC parse_datestr(const char *date_str, struct tm *ptm)
 return; /* don't fall through to end == ":" check */
 } else
 #endif
-//TODO: coreutils 6.9 also accepts "yyyy-mm-dd HH" (no minutes)
 {
 bb_error_msg_and_die(bb_msg_invalid_date, date_str);
 }
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -68,7 +67,20 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; void FAST_FUNC parse_datestr(const char *date_str, struct tm *ptm)
 end = '\0';
 /* else end != NUL and we error out */
 }
-} else if (date_str[0] == '&amp;lt; at &amp;gt;') {
+} else
+/* yyyy-mm-dd HH */
+if ((sscanf(date_str, "%u-%u-%u %u%c", &amp;amp;ptm-&amp;gt;tm_year,
+&amp;amp;ptm-&amp;gt;tm_mon, &amp;amp;ptm-&amp;gt;tm_mday,
+&amp;amp;ptm-&amp;gt;tm_hour, &amp;amp;end) &amp;gt;= 4) ||
+/* yyyy-mm-dd */
+(sscanf(date_str, "%u-%u-%u%c", &amp;amp;ptm-&amp;gt;tm_year,
+&amp;amp;ptm-&amp;gt;tm_mon, &amp;amp;ptm-&amp;gt;tm_mday, &amp;amp;end) &amp;gt;= 3))
+{
+ptm-&amp;gt;tm_year -= 1900; /* Adjust years */
+ptm-&amp;gt;tm_mon -= 1; /* Adjust month from 1-12 to 0-11 */
+} else
+/* unix timestamp */
+if (date_str[0] == '&amp;lt; at &amp;gt;') {
 time_t t = bb_strtol(date_str + 1, NULL, 10);
 if (!errno) {
 struct tm *lt = localtime(&amp;amp;t);
&lt;/pre&gt;</description>
    <dc:creator>Bartosz Golaszewski</dc:creator>
    <dc:date>2013-05-22T20:52:59</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37640">
    <title>ubimkvol -m and ubiformat</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37640</link>
    <description>&lt;pre&gt;I have an embedded use case where I need the -m option to ubimkvol and 
the ubiformat utility. As busybox doesn't currently support either, I am 
pulling in the full binaries from the mtd-utils package.

I haven't had a chance to review the code yet, but presumably if the -m 
option was as simple to implement as it would intuitively appear to be, 
somebody would have already done it :).

Before I go spend a lot of time getting familiar with busybox and 
mtd-utils code in the pursuit of adding this functionality, I wanted to 
get a little feedback if possible if anybody's already tried that and 
run into issues or determined that it's fairly complex and not worth 
doing within busybox.

Thanks much…
&lt;/pre&gt;</description>
    <dc:creator>Paul B. Henson</dc:creator>
    <dc:date>2013-05-21T18:02:58</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37635">
    <title>[PATCH v2] sulogin: allow system maintenance login if root password is empty</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37635</link>
    <description>&lt;pre&gt;The current password checking is unable to distinguish between the user
entering an empty password or pressing Control-D. As a result, an empty
password always results in normal startup.

We modify bb_ask to return NULL if Control-D is pressed without entering
a password. The sulogin applet is then modified to only proceed to
normal startup if bb_ask returns NULL. This covers EOF with no password,
interrupt by timeout and ^C.

Signed-off-by: Jonathan Liu &amp;lt;net147&amp;lt; at &amp;gt;gmail.com&amp;gt;
---
 libbb/bb_askpass.c   | 4 ++--
 loginutils/sulogin.c | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/libbb/bb_askpass.c b/libbb/bb_askpass.c
index fe2b506..e875bdd 100644
--- a/libbb/bb_askpass.c
+++ b/libbb/bb_askpass.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -65,8 +65,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; char* FAST_FUNC bb_ask(const int fd, int timeout, const char *prompt)
 i = 0;
 while (1) {
 int r = read(fd, &amp;amp;ret[i], 1);
-if (r &amp;lt; 0) {
-/* read is interrupted by timeout or ^C */
+if ((i == 0 &amp;amp;&amp;amp; r == 0) || r &amp;lt; 0) {
+/* EOF with no password, read is interrupted by timeout or ^C */
 ret = NULL;
 break;
 }
diff --git a/loginutils/sulogin.c b/loginutils/sulogin.c
index bd2b09e..6df0437 100644
--- a/loginutils/sulogin.c
+++ b/loginutils/sulogin.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -84,7 +84,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int sulogin_main(int argc UNUSED_PARAM, char **argv)
 "Give root password for system maintenance\n"
 "(or type Control-D for normal startup):");
 
-if (!cp || !*cp) {
+if (!cp) {
 bb_info_msg("Normal startup");
 return 0;
 }
&lt;/pre&gt;</description>
    <dc:creator>Jonathan Liu</dc:creator>
    <dc:date>2013-05-21T01:25:55</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37633">
    <title>[PATCH] make bb_ask zero its memory every time</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37633</link>
    <description>&lt;pre&gt;Hi,
this patch make bb_ask function zero its memory every time
as stated in a comment in sulogin.c.

--- libbb/bb_askpass.c.original 2013-05-20 15:27:45.309890577 +0200
+++ libbb/bb_askpass.c  2013-05-20 15:28:19.207572983 +0200
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -60,7 +60,10 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
        }
 
        if (!passwd)
-               passwd = xmalloc(sizeof_passwd);
+               passwd = xzalloc(sizeof_passwd);
+       else
+               memset(passwd, 0, sizeof_passwd);
+
        ret = passwd;
        i = 0;
        while (1) {

This is mostly paranoia.

Ciao,
Tito
_______________________________________________
busybox mailing list
busybox&amp;lt; at &amp;gt;busybox.net
http://lists.busybox.net/mailman/listinfo/busybox&lt;/pre&gt;</description>
    <dc:creator>Tito</dc:creator>
    <dc:date>2013-05-20T13:38:01</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37631">
    <title>[PATCH] sulogin: allow system maintenance login if root password is empty</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37631</link>
    <description>&lt;pre&gt;The current password checking is unable to distinguish between the user
entering an empty password or pressing Control-D. As a result, an empty
password always results in normal startup.

We modify bb_ask to store the EOF status after the null terminator if
the password is empty. This allows sulogin to properly check if
Control-D was pressed.

Signed-off-by: Jonathan Liu &amp;lt;net147&amp;lt; at &amp;gt;gmail.com&amp;gt;
---
 libbb/bb_askpass.c   | 3 +++
 loginutils/sulogin.c | 2 +-
 2 files changed, 4 insertions(+), 1 deletion(-)

diff --git a/libbb/bb_askpass.c b/libbb/bb_askpass.c
index fe2b506..4df0901 100644
--- a/libbb/bb_askpass.c
+++ b/libbb/bb_askpass.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -75,6 +75,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; char* FAST_FUNC bb_ask(const int fd, int timeout, const char *prompt)
  || ++i == sizeof_passwd-1 /* line limit */
 ) {
 ret[i] = '\0';
+/* if empty, store EOF status after null terminator */
+if (i == 0)
+ret[i + 1] = (r == 0);
 break;
 }
 }
diff --git a/loginutils/sulogin.c b/loginutils/sulogin.c
index bd2b09e..9fcf530 100644
--- a/loginutils/sulogin.c
+++ b/loginutils/sulogin.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -84,7 +84,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int sulogin_main(int argc UNUSED_PARAM, char **argv)
 "Give root password for system maintenance\n"
 "(or type Control-D for normal startup):");
 
-if (!cp || !*cp) {
+if (!cp || (!*cp &amp;amp;&amp;amp; cp[1])) {
 bb_info_msg("Normal startup");
 return 0;
 }
&lt;/pre&gt;</description>
    <dc:creator>Jonathan Liu</dc:creator>
    <dc:date>2013-05-20T11:07:33</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37624">
    <title>[PATCH] init: handle kexec clean reboot</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37624</link>
    <description>&lt;pre&gt;Currently, busybox init won't allow us to do a clean kexec; we have to
invoke kexec -e, which calls the reboot(LINUX_REBOOT_CMD_KEXEC) system
call directly, bypassing any shutdown/reboot init actions.

It'd be better if we can halt the system properly before the kernel
kexec, in order to unmount filesystems, take network devices down, etc.

As far as I can tell, this is handled in other inits in differring ways:
A kexec on systemd is performed by invoking `systemctl kexec`,
(alternatively `shutdown -r` will detect the presence of a loaded kexec
and change the reboot() magic accordingly). Upstart doesn't seem to
have native kexec support, so a clean kexec on Ubuntu is implemented
with an init script that calls `kexec -e` late in the shutdown path and
never returns.

This change adds a '-k' option to /sbin/reboot, which tells init (via
a SIGALRM) that we're requesting a kexec rather than a normal reboot.
init then handles this by specifying the correct magic to the reboot
syscall.

RFC: a couple of open items:

 * Not sure that SIGALRM is the best signal for this, let me know if
   there's something more appropriate

 * We could handle kexec in a method similar to upstart, by adding an
   rc.d script that performs the reboot() syscall with the correct
   kexec magic. However, this is a little inconsistent with the existing
   reboot methods.

Signed-off-by: Jeremy Kerr &amp;lt;jk&amp;lt; at &amp;gt;ozlabs.org&amp;gt;

---
 init/halt.c   |   12 +++++++++---
 init/init.c   |    9 +++++++--
 init/reboot.h |    6 ++++++
 3 files changed, 22 insertions(+), 5 deletions(-)

diff --git a/init/halt.c b/init/halt.c
index 7974adb..68a60a7 100644
--- a/init/halt.c
+++ b/init/halt.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -65,6 +65,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 //usage:     "\n-d SECDelay interval"
 //usage:     "\n-nDo not sync"
 //usage:     "\n-fForce (don't go through init)"
+//usage:     "\n-kReboot to preloaded kexec kernel"
 
 #include "libbb.h"
 #include "reboot.h"
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -101,9 +102,11 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int halt_main(int argc UNUSED_PARAM, char **argv)
 static const int magic[] = {
 RB_HALT_SYSTEM,
 RB_POWER_OFF,
-RB_AUTOBOOT
+RB_AUTOBOOT,
+RB_KEXEC,
 };
-static const smallint signals[] = { SIGUSR1, SIGUSR2, SIGTERM };
+static const smallint signals[] =
+{ SIGUSR1, SIGUSR2, SIGTERM, SIGALRM };
 
 int delay = 0;
 int which, flags, rc;
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -118,7 +121,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int halt_main(int argc UNUSED_PARAM, char **argv)
  * in order to not break scripts.
  * -i (shut down network interfaces) is ignored.
  */
-flags = getopt32(argv, "d:nfwi", &amp;amp;delay);
+flags = getopt32(argv, "d:nfwik", &amp;amp;delay);
 
 sleep(delay);
 
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -130,6 +133,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int halt_main(int argc UNUSED_PARAM, char **argv)
 if (!(flags &amp;amp; 2)) /* no -n */
 sync();
 
+if (applet_name[0] == 'r' &amp;amp;&amp;amp; flags &amp;amp; 0x20)
+which = 4;
+
 /* Perform action. */
 rc = 1;
 if (!(flags &amp;amp; 4)) { /* no -f */
diff --git a/init/reboot.h b/init/reboot.h
index 9497639..ea8b1ac 100644
--- a/init/reboot.h
+++ b/init/reboot.h
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -17,6 +17,12 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 # endif
 #endif
 
+#ifdef LINUX_REBOOT_CMD_KEXEC
+# define RB_KEXECLINUX_REBOOT_CMD_KEXEC
+#else
+# define RB_KEXEC0
+#endif
+
 /* Stop system and switch power off if possible.  */
 #ifndef RB_POWER_OFF
 # if defined(RB_POWERDOWN)
&lt;/pre&gt;</description>
    <dc:creator>Jeremy Kerr</dc:creator>
    <dc:date>2013-05-20T05:49:31</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37614">
    <title>Compiling using LLVM Clang : Nested functions</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37614</link>
    <description>&lt;pre&gt;Dear all, a quick question...

While trying to compile the latest busybox git version using clang
3.2-2+b1, I quickly discovered a nested function in the code...
apparently the only one. ;-) See below.

My question is... does anyone know how much bigger (approximately) the
code is without such a nested function?

Thanks in advance.

Cheers! :-)
Ben.

-       /* This is the only place in busybox where we use nested function.
-        * So far more standard alternatives were bigger. */
-       /* Auto decl suppresses "func without a prototype" warning: */
-       auto action* alloc_action(int sizeof_struct, action_fp f);
-       action* alloc_action(int sizeof_struct, action_fp f)
-       {
-               action *ap;
-               appp[cur_group] = xrealloc(appp[cur_group], (cur_action+2) * sizeof(*appp));
-               appp[cur_group][cur_action++] = ap = xzalloc(sizeof_struct);
-               appp[cur_group][cur_action] = NULL;
-               ap-&amp;gt;f = f;
-               IF_FEATURE_FIND_NOT( ap-&amp;gt;invert = invert_flag; )
-               IF_FEATURE_FIND_NOT( invert_flag = 0; )
-               return ap;
-       }

&lt;/pre&gt;</description>
    <dc:creator>Benjamin Lee</dc:creator>
    <dc:date>2013-05-15T12:07:30</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37605">
    <title>[PATCH] grep: Don't bail out on first mismatch if '-w' option is set</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37605</link>
    <description>&lt;pre&gt;This fixes bug 4520: 'grep -w fails when pattern is a strict substring
of a word'. If '-w' option is set - grep will retry to match against
the rest of the string after it finds a match not enclosed by delimiting
symbols.

Signed-off-by: Bartosz Golaszewski &amp;lt;bartekgola&amp;lt; at &amp;gt;gmail.com&amp;gt;
---
 findutils/grep.c |   25 ++++++++++++++-----------
 1 file changed, 14 insertions(+), 11 deletions(-)

diff --git a/findutils/grep.c b/findutils/grep.c
index 70f3516..fe8dab8 100644
--- a/findutils/grep.c
+++ b/findutils/grep.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -312,10 +312,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static int grep_file(FILE *file)
 smalluint found;
 int linenum = 0;
 int nmatches = 0;
-#if !ENABLE_EXTRA_COMPAT
-char *line;
-#else
 char *line = NULL;
+char *lineptr = NULL;
+#if ENABLE_EXTRA_COMPAT
 ssize_t line_len;
 size_t line_alloc_len;
 # define rm_so start[0]
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -388,32 +387,36 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static int grep_file(FILE *file)
 gl-&amp;gt;matched_range.rm_so = 0;
 gl-&amp;gt;matched_range.rm_eo = 0;
 #endif
+lineptr = line;
+ opt_w_again:
 if (
 #if !ENABLE_EXTRA_COMPAT
-regexec(&amp;amp;gl-&amp;gt;compiled_regex, line, 1, &amp;amp;gl-&amp;gt;matched_range, 0) == 0
+regexec(&amp;amp;gl-&amp;gt;compiled_regex, lineptr, 1, &amp;amp;gl-&amp;gt;matched_range, 0) == 0
 #else
-re_search(&amp;amp;gl-&amp;gt;compiled_regex, line, line_len,
+re_search(&amp;amp;gl-&amp;gt;compiled_regex, lineptr, line_len,
 /*start:*/ 0, /*range:*/ line_len,
 &amp;amp;gl-&amp;gt;matched_range) &amp;gt;= 0
 #endif
 ) {
 if (option_mask32 &amp;amp; OPT_x) {
 found = (gl-&amp;gt;matched_range.rm_so == 0
-         &amp;amp;&amp;amp; line[gl-&amp;gt;matched_range.rm_eo] == '\0');
+ &amp;amp;&amp;amp; lineptr[gl-&amp;gt;matched_range.rm_eo] == '\0');
 } else
 if (!(option_mask32 &amp;amp; OPT_w)) {
 found = 1;
 } else {
 char c = ' ';
 if (gl-&amp;gt;matched_range.rm_so)
-c = line[gl-&amp;gt;matched_range.rm_so - 1];
+c = lineptr[gl-&amp;gt;matched_range.rm_so - 1];
 if (!isalnum(c) &amp;amp;&amp;amp; c != '_') {
-c = line[gl-&amp;gt;matched_range.rm_eo];
-if (!c || (!isalnum(c) &amp;amp;&amp;amp; c != '_'))
+c = lineptr[gl-&amp;gt;matched_range.rm_eo];
+if (!c || (!isalnum(c) &amp;amp;&amp;amp; c != '_')) {
 found = 1;
+} else {
+lineptr += gl-&amp;gt;matched_range.rm_eo;
+goto opt_w_again;
+}
 }
-//BUG: "echo foop foo | grep -w foo" should match, but doesn't:
-//we bail out on first "mismatch" because it's not a word.
 }
 }
 }
&lt;/pre&gt;</description>
    <dc:creator>Bartosz Golaszewski</dc:creator>
    <dc:date>2013-05-14T21:01:55</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37598">
    <title>[PATCH] Support for '-v' argument for gzip and bzip2</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37598</link>
    <description>&lt;pre&gt;_______________________________________________
busybox mailing list
busybox&amp;lt; at &amp;gt;busybox.net
http://lists.busybox.net/mailman/listinfo/busybox&lt;/pre&gt;</description>
    <dc:creator>Bartosz Gołaszewski</dc:creator>
    <dc:date>2013-05-12T15:28:37</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37592">
    <title>Setting up to load firmware?</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37592</link>
    <description>&lt;pre&gt;Is there some documentation to show the steps needed to support 
loading firmware? 

I'm the current maintainer of the G4L project, and it includes 9 
kernels in the cd image, but the required firmware from users has 
been very limited, so it has just been building them into each 
kernel, but just had a situation were adding signal files didn't solve 
the problem. So, just added all the firmware from the bnx2x 
directory of the lnux-firmware to the kernel build and that did work, 
but it increased the kernel size from 8.7M to 12.5M. 

Once before I had tried to put firmware on the filesystem, but in 
the test it then didn't find it, so went back to what had worked by 
putting it in the kernel itself.

Don't know if it is a kernel option I have set or not set correctly?
If it is a busybox setting that isn't set correctly?
If it is something missing in the init.d rcS script?

I don't have any hardware that requires firmware, so setting up 
test is difficult. 

Thanks.

+----------------------------------------------------------+
  Michael D. Setzer II -  Computer Science Instructor      
  Guam Community College  Computer Center                  
  mailto:mikes&amp;lt; at &amp;gt;kuentos.guam.net                            
  mailto:msetzerii&amp;lt; at &amp;gt;gmail.com
  http://www.guam.net/home/mikes
  Guam - Where America's Day Begins                        
  G4L Disk Imaging Project maintainer 
  http://sourceforge.net/projects/g4l/
+----------------------------------------------------------+

http://setiathome.berkeley.edu (Original)
Number of Seti Units Returned:  19,471
Processing time:  32 years, 290 days, 12 hours, 58 minutes
(Total Hours: 287,489)

BOINC&amp;lt; at &amp;gt;HOME CREDITS
SETI        14741189.522008   |   EINSTEIN    11242028.609852
ROSETTA      7253471.928790   |   ABC         15959224.973599
&lt;/pre&gt;</description>
    <dc:creator>Michael D. Setzer II</dc:creator>
    <dc:date>2013-05-12T05:00:42</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37581">
    <title>Problem with dual Ethernet network routing and gateways</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37581</link>
    <description>&lt;pre&gt;I have a dual Ethernet AM335x board which I'm trying to set up, as follows:-

$ cat /etc/network/interfaces
auto lo eth0 eth1
iface lo inet loopback
iface eth1 inet static
address 10.0.101.1
netmask 255.255.0.0
gateway 10.0.0.1
iface eth0 inet static
address 10.1.101.1
netmask 255.255.0.0

$ ifconfig
eth0      Link encap:Ethernet  HWaddr 00:18:31:93:49:34
          inet addr:10.1.101.1  Bcast:0.0.0.0  Mask:255.255.0.0
          UP BROADCAST MULTICAST  MTU:1500  Metric:1
          RX packets:0 errors:0 dropped:0 overruns:0 frame:0
          TX packets:0 errors:0 dropped:0 overruns:0 carrier:0
          collisions:0 txqueuelen:1000
          RX bytes:0 (0.0 B)  TX bytes:0 (0.0 B)
          Interrupt:56

eth1      Link encap:Ethernet  HWaddr 00:18:31:93:49:35
          inet addr:10.0.101.1  Bcast:0.0.0.0  Mask:255.255.0.0
          UP BROADCAST RUNNING MULTICAST  MTU:1500  Metric:1
          RX packets:2756 errors:0 dropped:0 overruns:0 frame:0
          TX packets:607 errors:0 dropped:0 overruns:0 carrier:0
          collisions:0 txqueuelen:1000
          RX bytes:465648 (454.7 KiB)  TX bytes:168843 (164.8 KiB)

lo        Link encap:Local Loopback
          inet addr:127.0.0.1  Mask:255.0.0.0
          UP LOOPBACK RUNNING  MTU:65536  Metric:1
          RX packets:50 errors:0 dropped:0 overruns:0 frame:0
          TX packets:50 errors:0 dropped:0 overruns:0 carrier:0
          collisions:0 txqueuelen:0
          RX bytes:4066 (3.9 KiB)  TX bytes:4066 (3.9 KiB)

But my routing table is:-

$ route
Kernel IP routing table
Destination     Gateway         Genmask         Flags Metric Ref    Use Iface
default         10.1.0.1        0.0.0.0         UG    0      0        0 eth0
10.0.0.0        *               255.255.0.0     U     0      0        0 eth1
10.1.0.0        *               255.255.0.0     U     0      0        0 eth0

As you can see the gateway for eth1 has not been added to the routing table.

I'm using avahi and udhcpc, and I have done nothing special with the network
config.

So with only eth1 connected, I am unable to ping anything outside my local
network.

Can anyone tell me how to get the correct routing added automatically ?

Cheers
Mark J.
&lt;/pre&gt;</description>
    <dc:creator>Mark Jackson</dc:creator>
    <dc:date>2013-05-09T14:42:23</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37577">
    <title>mdev tmpfs 10 megabyte max limit?</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37577</link>
    <description>&lt;pre&gt;  Hi all.  I run Gentoo linux, with mdev replacing udev.  I
occasionally run a script that does quite a bit of copying back and
forth, and it uses /dev/shm to speed things up.  Yesterday, it started
blowing up on me.  After painfull debugging, I discovered that /dev/shm
is now only 10 megabytes.  The default linux size is 50% of ram.  Since
I have 3 gigabytes, that should allow 1.5 gigabytes in /dev/shm.  I
haven't run this script for a while, so the change may have been a few
months ago.  Is there an option I can set somewhere to override this
limit?  I tried remounting and bindmounting it, without any effect.

Here is my /etc/mtab for diagnostics.  Note the line...
mdev /dev tmpfs rw,nosuid,relatime,size=10240k,mode=755 0 0


rootfs / rootfs rw 0 0
/dev/root / ext2 rw,noatime,nodiratime,errors=continue 0 0
devtmpfs /dev devtmpfs rw,relatime,size=1551084k,nr_inodes=219109,mode=755 0 0
proc /proc proc rw,relatime 0 0
sysfs /sys sysfs rw,relatime 0 0
tmpfs /run tmpfs rw,nosuid,nodev,relatime,mode=755 0 0
devpts /dev/pts devpts rw,relatime,mode=600 0 0
shm /dev/shm tmpfs rw,nosuid,nodev,noexec,relatime 0 0
cgroup_root /sys/fs/cgroup tmpfs rw,nosuid,nodev,noexec,relatime,size=10240k,mode=755 0 0
openrc /sys/fs/cgroup/openrc cgroup rw,nosuid,nodev,noexec,relatime,release_agent=/lib/rc/sh/cgroup-release-agent.sh,name=openrc 0 0
cpuset /sys/fs/cgroup/cpuset cgroup rw,nosuid,nodev,noexec,relatime,cpuset 0 0
cpu /sys/fs/cgroup/cpu cgroup rw,nosuid,nodev,noexec,relatime,cpu 0 0
cpuacct /sys/fs/cgroup/cpuacct cgroup rw,nosuid,nodev,noexec,relatime,cpuacct 0 0
freezer /sys/fs/cgroup/freezer cgroup rw,nosuid,nodev,noexec,relatime,freezer 0 0
mdev /dev tmpfs rw,nosuid,relatime,size=10240k,mode=755 0 0
/dev/sda7 /home reiserfs rw,noatime,nodiratime,notail 0 1
/home/bindmounts/opt /opt none rw,bind 0 0
/home/bindmounts/var /var none rw,bind 0 0
/home/bindmounts/usr /usr none rw,bind 0 0
/home/bindmounts/tmp /tmp none rw,bind 0 0
binfmt_misc /proc/sys/fs/binfmt_misc binfmt_misc rw,nodev,noexec,nosuid 0 0
devpts /dev/pts devpts rw 0 0

&lt;/pre&gt;</description>
    <dc:creator>Walter Dnes</dc:creator>
    <dc:date>2013-05-08T23:32:00</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37576">
    <title>[PATCH] volume_id: fix ntfs attribute search</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37576</link>
    <description>&lt;pre&gt;len is declared as uint32_t but le16_to_cpu macro is used

Signed-off-by: Oliver Metz &amp;lt;oliver&amp;lt; at &amp;gt;freetz.org&amp;gt;
---
 util-linux/volume_id/ntfs.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/util-linux/volume_id/ntfs.c b/util-linux/volume_id/ntfs.c
index 7b2612f..0444e54 100644
--- a/util-linux/volume_id/ntfs.c
+++ b/util-linux/volume_id/ntfs.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -150,7 +150,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int FAST_FUNC volume_id_probe_ntfs(struct volume_id *id /*,uint64_t off*/)
 
 attr = (struct file_attribute*) &amp;amp;buf[attr_off];
 attr_type = le32_to_cpu(attr-&amp;gt;type);
-attr_len = le16_to_cpu(attr-&amp;gt;len);
+attr_len = le32_to_cpu(attr-&amp;gt;len);
 val_off = le16_to_cpu(attr-&amp;gt;value_offset);
 val_len = le32_to_cpu(attr-&amp;gt;value_len);
 attr_off += attr_len;
&lt;/pre&gt;</description>
    <dc:creator>Oliver Metz</dc:creator>
    <dc:date>2013-05-08T18:21:29</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37573">
    <title>[PATCH 1/1] grep: fix grep -x to not set REG_NOSUB</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37573</link>
    <description>&lt;pre&gt;When -F isn't specified (and !ENABLE_EXTRA_COMPAT), grep -x uses
regexec's regmatch_t output to determine if the match was the entire
line. However it also set the REG_NOSUB flag which makes it ignore the
regmatch_t argument.

Add an exception to the setting of REG_NOSUB for OPT_x and add some test
cases to test the behaviour of -x.

Signed-off-by: James Hogan &amp;lt;james.hogan&amp;lt; at &amp;gt;imgtec.com&amp;gt;
Cc: Natanael Copa &amp;lt;ncopa&amp;lt; at &amp;gt;alpinelinux.org&amp;gt;
Cc: Denys Vlasenko &amp;lt;vda.linux&amp;lt; at &amp;gt;googlemail.com&amp;gt;
---
 findutils/grep.c     |  2 +-
 testsuite/grep.tests | 14 ++++++++++++++
 2 files changed, 15 insertions(+), 1 deletion(-)

diff --git a/findutils/grep.c b/findutils/grep.c
index 70f3516..5611aac 100644
--- a/findutils/grep.c
+++ b/findutils/grep.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -710,7 +710,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int grep_main(int argc UNUSED_PARAM, char **argv)
 option_mask32 |= OPT_F;
 
 #if !ENABLE_EXTRA_COMPAT
-if (!(option_mask32 &amp;amp; (OPT_o | OPT_w)))
+if (!(option_mask32 &amp;amp; (OPT_o | OPT_w | OPT_x)))
 reflags = REG_NOSUB;
 #endif
 
diff --git a/testsuite/grep.tests b/testsuite/grep.tests
index 4781f22..b1d5b14 100755
--- a/testsuite/grep.tests
+++ b/testsuite/grep.tests
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -82,6 +82,20 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; testing "grep -F handles -i" "grep -F -i foo input ; echo \$?" \
 testing "grep can read regexps from stdin" "grep -f - input ; echo \$?" \
 "two\nthree\n0\n" "tw\ntwo\nthree\n" "tw.\nthr\n"
 
+# -x (whole line match)
+testing "grep -x (full match)" "grep -x foo input ; echo \$?" \
+"foo\n0\n" "foo\n" ""
+testing "grep -x (partial match 1)" "grep -x foo input ; echo \$?" \
+"1\n" "foo bar\n" ""
+testing "grep -x (partial match 2)" "grep -x foo input ; echo \$?" \
+"1\n" "bar foo\n" ""
+testing "grep -x -F (full match)" "grep -x -F foo input ; echo \$?" \
+"foo\n0\n" "foo\n" ""
+testing "grep -x -F (partial match 1)" "grep -x -F foo input ; echo \$?" \
+"1\n" "foo bar\n" ""
+testing "grep -x -F (partial match 2)" "grep -x -F foo input ; echo \$?" \
+"1\n" "bar foo\n" ""
+
 optional FEATURE_GREP_EGREP_ALIAS
 testing "grep -E supports extended regexps" "grep -E fo+" "foo\n" "" \
 "b\ar\nfoo\nbaz"
&lt;/pre&gt;</description>
    <dc:creator>James Hogan</dc:creator>
    <dc:date>2013-05-07T11:32:21</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37562">
    <title>Failed to add a script at shutdown</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37562</link>
    <description>&lt;pre&gt;Hello all. I'm trying to insert a simple test script at shutdown of a
device that uses BusyBox. I tried to add to inittab

::shutdown:/etc/init.d/test

before the "::shutdown:/bin/umount -a -r" line. test script is simply

#! /bin/sh
echo 'OOOOOOOOOOK!!!!!!!' &amp;gt; /OOK.txt
sync

I chmodded the script and I executed it, so I'm sure it works. I
powered off the device two times, but I found no output. What did I
wrong?

PS: the device is a Kobo Glo: https://github.com/kobolabs/Kobo-Reader
&lt;/pre&gt;</description>
    <dc:creator>Lucas Malor</dc:creator>
    <dc:date>2013-05-06T16:07:17</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37559">
    <title>Ntpd: bug and patch: not reporting lost sync</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37559</link>
    <description>&lt;pre&gt;Hello,

I am trying to find a way to keep hwclock in sync with the ntp-synced system time using busysbox ntpd.
Ntpd is able to start a script after each change and every 11 minutes (parameter -S) but there seems to be no way to
find out if the time is still synchronized i.e. there is at least one valid ntp server.
The attached patch exports one more value to the script (last_update_recv_time) so that the script can at least check if
the last update is within some limit. I consider this a workaround rather than a real solution because I would expect
ntpd to set stratum to 16 when loosing contact to the upstream ntp servers but I could not find a proper way to handle this.
Anyone any suggestions?

Greetings
  Andreas


[Patch] ntpd: set additional env variable "last_update_recv_time" when running script

Signed-off-by: Andreas Helmcke &amp;lt;ahe&amp;lt; at &amp;gt;helmcke.name&amp;gt;
---
 networking/ntpd.c | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/networking/ntpd.c b/networking/ntpd.c
index 0f4319e..eec01aa 100644
--- a/networking/ntpd.c
+++ b/networking/ntpd.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -828,7 +828,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; send_query_to_peer(peer_t *p)
 static void run_script(const char *action, double offset)
 {
 char *argv[3];
-char *env1, *env2, *env3, *env4;
+char *env1, *env2, *env3, *env4, *env5;

 if (!G.script_name)
 return;
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -847,6 +847,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static void run_script(const char *action, double offset)
 putenv(env3);
 env4 = xasprintf("%s=%f", "offset", offset);
 putenv(env4);
+env5 = xasprintf("%s=%f", "last_update_recv_time", G.last_update_recv_time);
+putenv(env5);
 /* Other items of potential interest: selected peer,
  * rootdelay, reftime, rootdisp, refid, ntp_status,
  * last_update_offset, last_update_recv_time, discipline_jitter,
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -862,10 +864,12 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static void run_script(const char *action, double offset)
 unsetenv("freq_drift_ppm");
 unsetenv("poll_interval");
 unsetenv("offset");
+unsetenv("last_update_recv_time");
 free(env1);
 free(env2);
 free(env3);
 free(env4);
+free(env5);

 G.last_script_run = G.cur_time;
 }
&lt;/pre&gt;</description>
    <dc:creator>Andreas Helmcke</dc:creator>
    <dc:date>2013-05-03T13:47:51</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37557">
    <title>ash "syntax error: bad substitution" on possibly proper SH script.</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37557</link>
    <description>&lt;pre&gt;I am unable to build glibc-2.17 with ash as /bin/sh, It fails in the 
middle of make with

sysdeps/unix/make-syscalls.sh: line 273: syntax error: bad substitution
sysdeps/unix/make-syscalls.sh: line 273: syntax error: bad substitution
sysdeps/unix/make-syscalls.sh: line 273: syntax error: bad substitution
../sysdeps/unix/make-syscalls.sh: line 273: syntax error: bad substitution


The glibc's scripts are full of crap and make does not even fail on 
make-syscalls.sh failure but later due to it, but I am able to build it 
with dash as /bin/sh so possibly the syntax is okay. The 273 line with 
its context

272# And finally, pipe this all into the compiler.
273echo '    ) | $(compile-syscall) '"\
274\$(foreach p,\$(patsubst %$file,%,\$(basename 
\$(&amp;lt; at &amp;gt;F))),\$(\$(p)CPPFLAGS))"

&lt;/pre&gt;</description>
    <dc:creator>Piotr Karbowski</dc:creator>
    <dc:date>2013-05-03T12:50:10</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37552">
    <title>FYI: struggling with 'int optind'</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37552</link>
    <description>&lt;pre&gt;Hello,

I am struggling to get the busybox dhcp server cross-compiled (ARM) for 
the embedded RTOS eCos.
I took the latest code from git.
I have this error:
dhcpd.c:328:10: error: ‘optind’ undeclared (first use in this function)

I found out that 'optind' is declared in /usr/include/getopt.h.
This is given by the toolchain.

'int optind' is defined in your toolchain libraries.
This is OK for a linux (cross-)compilation, but not for an eCos one.

Is it correct that busybox only works (and compiles) for a system with a 
shell?
I don't compile the busybox ash shell (or another one) and eCos does not 
have a shell. So I guess I will have to work around this.

Kind regards,
Jürgen

P.S.: I started the email before I searched in a ARM-toolchain for 
linux, where I found my answers. But I decided still to send it.

&lt;/pre&gt;</description>
    <dc:creator>Lambrecht Jürgen</dc:creator>
    <dc:date>2013-05-02T12:47:49</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37543">
    <title>Best way to use dhcpc / avahi without delaying other init scripts ?</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37543</link>
    <description>&lt;pre&gt;I'm trying (and failing !!) to work out how best to use dhcpc and avahi
together.

Ideally I'd like udhcpc to start up, try to get a lease and, if the
lease request fails, use avahi to get a local ip address.

I have this working, but the dhcp request can taken some time (or even
fail if no dhcp server is present), and I am seeing delays of several
seconds before my other init scripts run.  I have dual ethernet ports
leading to about a 10seconf delay if no dhcp server is present.

To prevent other init scripts from being delayed, udhcpc should
instantly go into background mode (see [1]).

But the '-d' option in [1] is not present so I guess this patch either
never made it, or has come and gone.

I have tried the '-b' option, but this only puts udhcpc to the
background *after* if fails.

Even using options "-T 1 -t 1", I still get delays.

Can anyone explain the best options to use ?

Or am I going about this the wrong way ?

Any help would be greatly appreciated.

Regards
Mark J.

[1] http://lists.busybox.net/pipermail/busybox/2003-September/043366.html
&lt;/pre&gt;</description>
    <dc:creator>Mark Jackson</dc:creator>
    <dc:date>2013-04-30T18:24:19</dc:date>
  </item>
  <item rdf:about="http://comments.gmane.org/gmane.linux.busybox/37541">
    <title>How to get security patches from the busybox development branch</title>
    <link>http://comments.gmane.org/gmane.linux.busybox/37541</link>
    <description>&lt;pre&gt;Hello Everyone,

I am trying to port security fixes from the main development branch to
the 1_8_2 branch, to maintain it in my free time, is there any way
that i can identify which are security fixes and which are not? I
think it really takes lot of time by reading thru each and every
commit in the git from the 1_8_2, but is there any tag that i can grep
for to find which are the security fixes?

thanks,
&lt;/pre&gt;</description>
    <dc:creator>devendra.aaru</dc:creator>
    <dc:date>2013-04-25T04:00:12</dc:date>
  </item>
  <textinput rdf:about="http://search.gmane.org/?group=$group=gmane.linux.busybox">
    <title>Search Engine</title>
    <description>Search the mailing list at Gmane</description>
    <name>query</name>
    <link>http://search.gmane.org/?group=$group=gmane.linux.busybox</link>
  </textinput>
</rdf:RDF>

diff --git a/init/init.c b/init/init.c
index 15aad47..7c806d7 100644
--- a/init/init.c
+++ b/init/init.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -175,8 +175,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 #define CTRLALTDEL  0x20
 /*
  * Start these before killing all processes in preparation for
  * running RESTART actions or doing low-level halt/reboot/poweroff
  * (initiated by SIGUSR1/SIGTERM/SIGUSR2).
  * Wait for completion before proceeding.
  */
 #define SHUTDOWN    0x40
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -393,6 +393,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static void reset_sighandlers_and_unblock_sigs(void)
 + (1 &amp;lt;&amp;lt; SIGHUP)
 + (1 &amp;lt;&amp;lt; SIGTSTP)
 + (1 &amp;lt;&amp;lt; SIGSTOP)
++ (1 &amp;lt;&amp;lt; SIGALRM)
 , SIG_DFL);
 sigprocmask_allsigs(SIG_UNBLOCK);
 }
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -811,6 +812,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static void halt_reboot_pwoff(int sig)
 } else if (sig == SIGUSR2) {
 m = "poweroff";
 rb = RB_POWER_OFF;
+} else if (sig == SIGALRM) {
+m = "kexec";
+rb = RB_KEXEC;
 }
 message(L_CONSOLE, "Requesting system %s", m);
 pause_and_low_level_reboot(rb);
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1124,6 +1128,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; int init_main(int argc UNUSED_PARAM, char **argv)
 + (1 &amp;lt;&amp;lt; SIGUSR1) /* halt */
 + (1 &amp;lt;&amp;lt; SIGTERM) /* reboot */
 + (1 &amp;lt;&amp;lt; SIGUSR2) /* poweroff */
++ (1 &amp;lt;&amp;lt; SIGALRM) /* kexec */
 , halt_reboot_pwoff);
 signal(SIGQUIT, restart_handler); /* re-exec another init */
 
@@
 /*
  * Start these before killing all processes in preparation for
- * running RESTART actions or doing low-level halt/reboot/poweroff
- * (initiated by SIGUSR1/SIGTERM/SIGUSR2).
+ * running RESTART actions or doing low-level halt/reboot/poweroff/kexec
+ * (initiated by SIGUSR1/SIGTERM/SIGUSR2/SIGALRM).
  * Wait for completion before proceeding.
  */